set(PRT_PROJECT prt)
get_filename_component(PRT_INSTALL_PATH ${CMAKE_CURRENT_LIST_DIR} DIRECTORY)


### establish main directories

set(PRT_INCLUDE_PATH ${PRT_INSTALL_PATH}/include)
set(PRT_LIBRARY_PATH ${PRT_INSTALL_PATH}/bin)
set(PRT_EXTENSION_PATH ${PRT_INSTALL_PATH}/lib)


### try to find libraries

find_library(PRT_CORE_LIBRARY    NAMES com.esri.prt.core PATHS ${PRT_LIBRARY_PATH} NO_DEFAULT_PATH)
find_library(PRT_GLUTESS_LIBRARY NAMES glutess           PATHS ${PRT_LIBRARY_PATH} NO_DEFAULT_PATH)

if(WIN32) # find_library only finds import libs on windows, need to find the actual libraries via find_file
	set(PF ${CMAKE_SHARED_LIBRARY_PREFIX})
	set(SF ${CMAKE_SHARED_LIBRARY_SUFFIX})

	find_file(PRT_CORE_SHARED_LIBRARY      NAMES ${PF}com.esri.prt.core${SF}       PATHS ${PRT_LIBRARY_PATH}   NO_DEFAULT_PATH)
	find_file(PRT_GLUTESS_SHARED_LIBRARY   NAMES ${PF}glutess${SF}                 PATHS ${PRT_LIBRARY_PATH}   NO_DEFAULT_PATH)

	find_file(PRT_CODECS_LIBRARY           NAMES ${PF}com.esri.prt.codecs${SF}     PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_file(PRT_ADAPTORS_LIBRARY         NAMES ${PF}com.esri.prt.adaptors${SF}   PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_file(PRT_ALEMBIC_LIBRARY          NAMES ${PF}com.esri.prt.alembic${SF}    PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_file(PRT_VOB_LIBRARY              NAMES ${PF}com.esri.prt.vob${SF}        PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_file(PRT_VUE_LIBRARY              NAMES ${PF}VueExport${SF}               PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)

	find_file(PRT_UNREAL_LIBRARY           NAMES ${PF}com.esri.prt.unreal${SF}     PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_file(PRT_UNREAL_DS                NAMES ${PF}DatasmithSDK${SF}            PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)

	find_file(PRT_USD_LIBRARY              NAMES ${PF}com.esri.prt.usd${SF}        PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_file(PRT_USD_MS_LIBRARY           NAMES ${PF}prt_usd_ms${SF}              PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_file(PRT_USD_TBB_LIBRARY          NAMES ${PF}prt_tbb${SF} ${PF}prt_tbb_debug${SF} PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)

	find_file(PRT_ODA_LIBRARY              NAMES ${PF}com.esri.prt.oda${SF}        PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
else()
	find_library(PRT_CODECS_LIBRARY        NAMES com.esri.prt.codecs               PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_library(PRT_ADAPTORS_LIBRARY      NAMES com.esri.prt.adaptors             PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_library(PRT_ALEMBIC_LIBRARY       NAMES com.esri.prt.alembic              PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)

	find_library(PRT_UNREAL_LIBRARY        NAMES com.esri.prt.unreal               PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_library(PRT_UNREAL_DS             NAMES DatasmithSDK                      PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)

	find_library(PRT_USD_LIBRARY           NAMES com.esri.prt.usd                                            PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_library(PRT_USD_MS_LIBRARY        NAMES prt_usd_ms                                                  PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_library(PRT_USD_TBB_LIBRARY       NAMES prt_tbb prt_tbb_debug libprt_tbb.so.2 libprt_tbb_debug.so.2 PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)

	find_library(PRT_ODA_LIBRARY           NAMES com.esri.prt.oda                  PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
	find_library(PRT_ODA_CRYPT_LIBRARY     NAMES libcrypto                         PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
endif()

if(${CMAKE_SYSTEM_NAME} STREQUAL "Emscripten")
	find_library(PRT_UTIL_LIBRARY          NAMES com.esri.prt.util                 PATHS ${PRT_LIBRARY_PATH}   NO_DEFAULT_PATH)
	find_library(PRT_CORE_CGAL_LIBRARY     NAMES com.esri.prt.core.cgal            PATHS ${PRT_LIBRARY_PATH}   NO_DEFAULT_PATH)
	find_library(PRT_CODECS_COMMON_LIBRARY NAMES com.esri.prt.codecs.common        PATHS ${PRT_EXTENSION_PATH} NO_DEFAULT_PATH)
endif()


### set output variables

# the set of libs that need to be linked to the client at compile time
list(APPEND PRT_LINK_LIBRARIES ${PRT_CORE_LIBRARY})
list(APPEND PRT_LINK_LIBRARIES ${PRT_GLUTESS_LIBRARY})

# the set of libs to install with the client app/lib for runtime
list(APPEND PRT_LIBRARIES ${PRT_CORE_LIBRARY})
if(PRT_CORE_SHARED_LIBRARY)
	list(APPEND PRT_LIBRARIES ${PRT_CORE_SHARED_LIBRARY})
endif()
list(APPEND PRT_LIBRARIES ${PRT_GLUTESS_LIBRARY})
if(PRT_GLUTESS_SHARED_LIBRARY)
	list(APPEND PRT_LIBRARIES ${PRT_GLUTESS_SHARED_LIBRARY})
endif()

# the set of extension libs to install with client app/lib for runtime
list(APPEND PRT_EXT_LIBRARIES ${PRT_ADAPTORS_LIBRARY})
list(APPEND PRT_EXT_LIBRARIES ${PRT_CODECS_LIBRARY})
if(PRT_ALEMBIC_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_ALEMBIC_LIBRARY})
endif()
if(PRT_VOB_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_VOB_LIBRARY})
endif()
if(PRT_VUE_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_VUE_LIBRARY})
endif()
if(PRT_UNREAL_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_UNREAL_LIBRARY})
endif()
if(PRT_UNREAL_DS)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_UNREAL_DS})
endif()
if(PRT_USD_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_USD_LIBRARY})
endif()
if(PRT_USD_MS_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_USD_MS_LIBRARY})
endif()
if(PRT_USD_TBB_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_USD_TBB_LIBRARY})
endif()
if(PRT_ODA_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_ODA_LIBRARY})
endif()
if(PRT_ODA_CRYPT_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_ODA_CRYPT_LIBRARY})
endif()
if(PRT_IFC_LIBRARY)
	list(APPEND PRT_EXT_LIBRARIES ${PRT_IFC_LIBRARY})
endif()

set(PRT_NAME ArcGIS Procedural Runtime)
set(PRT_VERSION_MAJOR 3)
set(PRT_VERSION_MINOR 1)
set(PRT_VERSION_MICRO 9666)

include(FindPackageHandleStandardArgs)
find_package_handle_standard_args(${PRT_PROJECT} DEFAULT_MSG PRT_LINK_LIBRARIES PRT_LIBRARIES PRT_EXT_LIBRARIES PRT_INCLUDE_PATH)
